# NixOS Configuration

This is a Nix flake for configuring NixOS.

### Installing to new host

Download latest [NixOS build](https://nixos.org/download.html#nixos-iso), boot and install with username "insert", then configure the hostname in `/etc/nixos/configuration.nix` & `sudo nixos-rebuild switch`, and finally reboot.

Now we can configure the flake:

```bash
# clone the flake
git clone https://git.is.horse/izzy/nix ~/.nix
cd ~/.nix

# copy hardware scan
mkdir -p ~/.nix/hosts/$HOSTNAME
cp /etc/nixos/hardware-configuration.nix ~/.nix/hosts/$HOSTNAME/hardware-configuration.nix
```

Now create the `~/.nix/hosts/$HOSTNAME/configuration.nix` file, ensuring it contains:
- An import of the hardware scan
- An import of the configuration
- The correct hostname
- The Nix state version
- Any machine-specific configuration (Bluetooth, sound, graphics)

  Use `/etc/nixos/configuration.nix` as a reference for detected options.

Make sure to generate an SSH key:

```bash
ssh-keygen -t ed25519
```

And upload the public key to GitHub and GitLab for authorisation.

Now you can commit, push, and build:

```bash
# commit
cd ~/.nix
git add .
git commit -m "feat: add host abc"
git push

# build
sudo nixos-rebuild --flake . switch
```

### Updating the system

Updating the system is straightforward:

```bash
# occasionally run
sudo nix-collect-garbage -d

# update the flake
nix flake update

# rebuild
sudo nixos-rebuild --flake . switch
```

### Configure Git signing

To configure hardware key signing on a new device, first the public key must be imported to the system, do this using Kleopatra and import `./files/keys/*`.

Next, plug in the hardware key and then:

```bash
# run the following to detect the card
gpg --card-status
# .. now you can sign using Git
```
