# This is the shared user configuration
#
# Options can be found here:
# https://home-manager-options.extranix.com/

{
  pkgs,
  inputs,
  device,
  lib,
  ...
}:
{
  # use home manager
  programs.home-manager.enable = true;

  # firefox
  programs.firefox = {
    enable = true;
    package = inputs.firefox-flake.packages.${pkgs.system}.firefox-nightly-bin.override {
      extraPolicies = {
        DisablePocket = true;
      };
    };
  };

  # chromium
  programs.chromium = {
    enable = true;
  };

  # vscode
  programs.vscode = {
    enable = true;
  };

  # alacritty
  programs.alacritty = {
    enable = true;
    settings = {
      window = {
        opacity = 0.75;
      };
    };
  };

  # micro text editor
  programs.micro = {
    enable = true;
    settings = {
      mkparents = true;
    };
  };

  # gpg
  programs.gpg = {
    enable = true;
  };

  # gpg-agent
  services.gpg-agent = {
    enable = true;
  };

  # git
  programs.git = {
    enable = true;
    userName = "izzy";
    userEmail = "me@insrt.uk";
    signing = {
      key = "me@insrt.uk";
      signByDefault = true;
    };
    extraConfig = {
      init.defaultBranch = "main";
    };
  };

  # suggests installing programs which aren't found
  programs.nix-index = {
    enable = true;
    enableFishIntegration = true;
  };

  # OBS Studio
  programs.obs-studio = {
    enable = true;
  };

  # Java
  programs.java = {
    enable = true;
    package = pkgs.temurin-bin-17; # JDK 17 (Temurin distribution)
  };

  # music eq
  services.easyeffects = {
    enable = true;
  };

  # KDE Connect
  services.kdeconnect = {
    enable = true;
    indicator = true;
  };

  # install other programs by name
  home.packages =
    with pkgs;
    [
      # basics
      thunderbird # email client
      obsidian # Obsidian
      # insecure: logseq # Logseq
      speedcrunch # speedcrunch
      onlyoffice-bin # OnlyOffice desktop editors
      tor-browser-bundle-bin # Tor browser
      # zed-editor # Zed editor -- tried to build from source

      # comms
      (discord.override {
        withOpenASAR = true;
        withVencord = true;
      }) # messaging
      revolt-desktop # messaging
      element-desktop # messaging

      # games
      prismlauncher # minecraft launcher (woke)

      # edu
      anki # flashcards

      # misc.
      krita # drawing
      vlc # cone-themed video player
      mpv # video player
      jellyfin-media-player # jellyfin media player
      jellyfin-mpv-shim # jellyfin+mpv

      # tools
      trayscale # GUI for Tailscale
      ffmpeg # video transcoding
      kdePackages.kleopatra # key management
      nixpkgs-fmt # format nix flakes
      nextcloud-client # nextcloud client
      simplescreenrecorder # simple screen recorder
      kdePackages.filelight # Disk space analyser
      imagemagick # image processing
      mosh # ssh over UDP
    ]
    ++ lib.optionals (device == "framework") [
      # tools
      virt-manager # virtual machine manager
      mongodb-compass # mongodb database client
      rquickshare # quickshare

      # games
      moonlight-qt
      customPkgs.unofficial-homestuck-collection

      # system monitoring
      glances

      # Godot development
      godot-mono
      jetbrains.rider
    ]
    ++ lib.optionals false [
      # stuff i'm not using rn:

      barrier # software kvm software
      ghostty # terminal emulator
    ];

  # mpv config
  home.file.".config/mpv/mpv.conf".source = ./mpv.conf;

  #
  ### Don't change these!
  #

  # state version for migrations
  home.stateVersion = "24.05";

  # https://github.com/nix-community/home-manager/issues/2064#issuecomment-887300055
  systemd.user.targets.tray = {
    Unit = {
      Description = "Home Manager System Tray";
      Requires = [ "graphical-session-pre.target" ];
    };
  };
}
