{ config, pkgs, ... }:

{
  imports =
    [
      # include hardware scan
      ./hardware-configuration.nix
      # include our shared configuration
      ../../configuration.nix
    ];

  networking.hostName = "framework";

  # Configure timezone
  time.timeZone = "Europe/London";
  # time.timeZone = "Europe/Rome";

  # Enable Bluetooth
  hardware.bluetooth.enable = true;

  # Enable fingerprint reader & firmware manager
  services.fprintd.enable = true;
  services.fwupd.enable = true;

  # Enable sound
  hardware.pulseaudio.enable = false;
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
  };

  # Automatically update Thunderbird "Start week on:" preference to current day
  systemd.services.thunderbird-update-week = {
    enable = true;
    description = "Update Thunderbird week preference to current day";
    unitConfig = {
      Type = "simple";
    };
    serviceConfig = {
      ExecStart = "${pkgs.bash}/bin/bash /home/insert/.local/share/thunderbird-update.sh";
      User = "insert";
      Group = "users";
    };
    wantedBy = [ "timers.target" ];
  };

  systemd.timers.thunderbird-update-week = {
    timerConfig = {
      OnCalendar = "daily";
      Persistent = true;
      Unit = "thunderbird-update-week.service";
    };
  };

  #
  ### Don't change these!
  #

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "24.05"; # Did you read the comment?
}
